from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class CareerBase(BaseModel):
    name: str = Field(..., description="Name of the career")
    description: Optional[str] = Field(None, description="Description of the career")
    tech_career: bool = Field(..., description="Whether the career is a tech career or not")

class CareerCreate(CareerBase):
    pass

class CareerUpdate(CareerBase):
    name: Optional[str] = Field(None, description="Name of the career")
    description: Optional[str] = Field(None, description="Description of the career")
    tech_career: Optional[bool] = Field(None, description="Whether the career is a tech career or not")

class CareerSchema(CareerBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True